

var UniSDK = UniSDK || {

    initCallback: null,
    loginCallback: null,
    payCallback: null,
    logoutCallback: null,

    isAndroid: function () {
        var u = navigator.userAgent;
        var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Linux') > -1;
        return isAndroid;
    },

    isIos: function() {
        var u = navigator.userAgent;
        var isIOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
        return isIOS;
    },

    init: function(initCallback, logoutCallback){
        this.initCallback = initCallback;
        this.logoutCallback = logoutCallback;
        if (this.isAndroid()) {
            window.android.init();
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "init" });
        }
    },

    login: function(loginCallback){
        this.loginCallback = loginCallback;
        if (this.isAndroid()) {
            window.android.login();
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "login" });
        }
    },

    pay: function(orderInfo, gameData, payCallback){
        this.payCallback = payCallback;
        if (this.isAndroid()) {
            window.android.pay(JSON.stringify(orderInfo), JSON.stringify(gameData));
        }else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "pay", data: {orderInfo:orderInfo, gameData: gameData}});
        }
    },

    showFloat: function(){
        if (this.isAndroid()) {
            window.android.showFloat();
        }else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "showFloat"});
        }
    },

    hideFloat: function(){
        if (this.isAndroid()) {
            window.android.hideFloat();
        }else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "hideFloat"});
        }
    },

    logout: function(gameData){
        if (this.isAndroid()) {
            window.android.logout(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "logout", data: {gameData:gameData}});
        }
    },

    exit: function(gameData){
        if (this.isAndroid()) {
            window.android.exit(JSON.stringify(gameData));
        } 
    },

    enterGame: function(gameData){
        if (this.isAndroid()) {
            window.android.enterGame(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "enterGame", data: {gameData:gameData}});
        }
    },

    createRole: function(gameData){
        if (this.isAndroid()) {
            window.android.createRole(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "createRole", data: {gameData:gameData}});
        }
    },

    levelUp: function(gameData){
        if (this.isAndroid()) {
            window.android.levelUp(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "levelUp", data: {gameData:gameData}});
        }
    },

    exitGame: function(gameData){
        if (this.isAndroid()) {
            window.android.exitGame(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "exitGame", data: {gameData:gameData}});
        }
    },

    getChannelId: function(){
        if (this.isAndroid()) {
            return window.android.getChannelId();
        }  else if(this.isIos()) {
            return window._fg_unisdk_private_get_channel_id_result;
        }    
    },

    showToast: function(content){
        if (this.isAndroid()) {
            return window.android.showToast(content);
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "showToast", data: {content:content}});
        }
    },

    clearCache: function(){
        if (this.isAndroid()) {
            return window.android.clearCache();
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "clearCache"});
        }
    },

    getDeviceId: function(){
        if (this.isAndroid()) {
            return window.android.getDeviceId();
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "getDeviceId"});
        }
    },
    
    onResUpdate: function(gameData){
        if (this.isAndroid()) {
            return window.android.onResUpdate(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "onResUpdate", data: {gameData:gameData}});
        }
    },
    
    onRegisterFinish: function(gameData){
        if (this.isAndroid()) {
            return window.android.onRegisterFinish(JSON.stringify(gameData));
        } else if(this.isIos()) {
            window.webkit.messageHandlers.ios.postMessage({ op: "onRegisterFinish", data: {gameData:gameData}});
        }
    }

}

console.log("UniSDK load");